@@ -14,7 +14,13 @@ class SkyApiClient(object):
         self.subscription_key = subscription_key
         self.access_token = access_token
 
-    def request(self, method: str, path: str, data: Dict[str, str] = None, params: Dict[str, Any] = None):
+    def request(
+        self, method: str, path: str, data: Dict[str, str] = None, page=1, page_size=500, params: Dict[str, Any] = None
+    ):
+        params = params or {}
+        params['limit'] = page_size
+        params['offset'] = ((page - 1) * params['limit']) if page >= 1 else 1
+
         response = requests.request(
             method=method,
             url='{}/{}'.format(BASE_URL, path),
