@@ -1,6 +1,8 @@
 from sky_api_client.entity.base import Entity
+from sky_api_client.entity.registry import EntityRegistry
 
 
+@EntityRegistry.register('constituent')
 class Constituent(Entity):
     LIST_URL = '/constituent/v1/constituents/'
     CREATE_URL = '/constituent/v1/constituents/'
