@@ -6,4 +6,7 @@ from sky_api_client.entity.registry import EntityRegistry
 class ConstituentCode(Entity):
     LIST_URL = '/constituent/v1/constituents/{id}/constituentcodes'
     GET_URL = '/constituent/v1/constituents/constituentcodes/{id}'
+    CREATE_URL = '/constituent/v1/constituentcodes/'
+    UPDATE_URL = '/constituent/v1/constituentcodes/{id}'
+    DELETE_URL = '/constituent/v1/constituentcodes/{id}'
     TYPES_URL = '/constituent/v1/constituentcodetypes'
