@@ -4,7 +4,7 @@ from sky_api_client.entity.registry import EntityRegistry
 
 @EntityRegistry.register('event')
 class Event(Entity):
-    LIST_URL = '/event/v1/events'
+    LIST_URL = '/event/v1/eventlist'
     CREATE_URL = '/event/v1/events'
     GET_URL = '/event/v1/events/{id}'
     UPDATE_URL = '/event/v1/events/{id}'
